﻿# Examples README

The `examples` directory houses a variety of sub-directories, each focusing on specific functionalities, tests, or demonstrations. These sub-directories serve as a comprehensive resource for understanding the system.

---


## **Flybase Module**

- **[`flybase`](./flybase)**: Focused on the Flybase module, the examples here are designed to provide insights into how this specific component works and can be used.
   - [`flybase-deduced-queries.metta`](flybase/flybase-deduced-queries.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/flybase-deduced-queries.metta.html): Contains queries deduced from Flybase data analysis.
   - [`flybase-loader-size-estimates.metta`](flybase/flybase-loader-size-estimates.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/flybase-loader-size-estimates.metta.html): Size estimates and optimizations for the Flybase loader.
   - [`flybase-loader.metta`](flybase/flybase-loader.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/flybase-loader.metta.html): Loader script for Flybase datasets.
   - [`flybase-vspace.metta`](flybase/flybase-vspace.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/flybase-vspace.metta.html): Virtual space configuration for Flybase.
   - [`flybase-deduced-connections.metta`](flybase/flybase-deduced-connections.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/flybase-deduced-connections.metta.html): Mapping and connections deduced in Flybase.
   - [`flybase-deduced-types.metta`](flybase/flybase-deduced-types.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/flybase-deduced-types.metta.html): Type definitions and structures deduced in Flybase.
  - **[`output~`](./flybase/output~)**: Output files and processed data from Flybase.
    - [`flybase-deduced.metta`](flybase/output~/flybase-deduced.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/output~/flybase-deduced.metta.html): Deduced results and insights from Flybase data.
    - [`flybase-mined-flat.metta`](flybase/output~/flybase-mined-flat.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/output~/flybase-mined-flat.metta.html): Flat structure representation of mined data in Flybase.
    - [`flybase-mined.metta`](flybase/output~/flybase-mined.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/output~/flybase-mined.metta.html): Original mined data from Flybase.
  - **[`sanity`](./flybase/sanity)**: Sanity checks and basic tests for Flybase module.
    - [`download_file.metta`](flybase/sanity/download_file.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/sanity/download_file.metta.html): Tests downloading a remote version of Flybase.
    - [`load_all_of_flybase.metta`](flybase/sanity/load_all_of_flybase.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/sanity/load_all_of_flybase.metta.html): Demonstrates loading all 54 million atoms in under 30 seconds.
    - [`simple_query1.metta`](flybase/sanity/simple_query1.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/sanity/simple_query1.metta.html): Queries using the loaded atoms that complete in under a second.
    - [`simple_query2_llm.metta`](flybase/sanity/simple_query2_llm.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/sanity/simple_query2_llm.metta.html): Combined queries with large language models.

### Flybase Integration with DAS and VSPACE

#### **Flybase with Distributed Atomspace (DAS) Integration**
- **[`flybase/from_das`](./flybase/from_das)**: Showcases the integration of Flybase with Distributed Atomspace (DAS), a system for managing and processing distributed atom-based data.
  - [`flybase_rust_uses_python_das.metta`](./flybase/from_das/flybase_rust_uses_python_das.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/from_das/flybase_rust_uses_python_das.metta.html): Demonstrates how Flybase utilizes Python and Rust to interact with DAS, enhancing its data analysis and processing capabilities.

#### **Flybase with Rust-Only Implementation**
- **[`flybase/from_rust`](./flybase/from_rust)**: Features Flybase loaded exclusively in Rust
  - [`flybase_rust_only.metta`](./flybase/from_rust/flybase_rust_only.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/from_rust/flybase_rust_only.metta.html): Illustrates the pure Rust implementation of Flybase, highlighting its efficiency and direct integration with system-level functionalities.

#### **Flybase with VSPACE (Version Space) Integration**
- **[`flybase/from_vspace`](./flybase/from_vspace)**: Using Rust to access Flybase with VSPACE ( hosting 56 million atoms )
  - [`flybase_rust_uses_python_vspace.metta`](./flybase/from_vspace/flybase_rust_uses_python_vspace.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/flybase/from_vspace/flybase_rust_uses_python_vspace.metta.html): Showcases Flybase leveraging Python VSPACE within a Rust environment, focusing on efficient handling and manipulation of a vast space containing millions of atoms.


## Hyperon Miner Examples

- **[`extended_compat/hyperon-miner/`](extended_compat/hyperon-miner/):** Hyperon miner directory
    - [`data/sample.metta`](extended_compat/hyperon-miner/data/sample.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-miner/data/sample.metta.html): Sample data for Hyperon miner testing.
    - [`utils/MinerUtils.metta`](extended_compat/hyperon-miner/utils/MinerUtils.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-miner/utils/MinerUtils.metta.html): Utility functions for Hyperon mining operations.
   - [`match/MinerMatchTest.metta`](extended_compat/hyperon-miner/match/MinerMatchTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-miner/match/MinerMatchTest.metta.html): Test cases for Hyperon miner matching algorithms.
   - [`match/MinerMatch.metta`](extended_compat/hyperon-miner/match/MinerMatch.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-miner/match/MinerMatch.metta.html): Implementation of matching algorithms for Hyperon miner.


## Extended Compatibility Examples

### Combinator Logic Experiments
- **[`extended_compat/metta-examples/combinator_logic_experiments/`](extended_compat/metta-examples/combinator_logic_experiments/):** Combinator Logic Experiments Directory
   - [`y_comb_examples.metta`](extended_compat/metta-examples/combinator_logic_experiments/y_comb_examples.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/combinator_logic_experiments/y_comb_examples.metta.html): Examples and experiments with Y combinators.

### Logic
- **[`extended_compat/metta-examples/logic/`](extended_compat/metta-examples/logic/):** Metta Logic Directory
   - [`puzzle.metta`](extended_compat/metta-examples/logic/puzzle.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/logic/puzzle.metta.html): Logic puzzles and solutions in Metta.
   - [`all_any.metta`](extended_compat/metta-examples/logic/all_any.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/logic/all_any.metta.html): Implementations of universal and existential quantifiers.
   - [`memb.metta`](extended_compat/metta-examples/logic/memb.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/logic/memb.metta.html): Member checking functions in logical expressions.

### SICP Book Examples
- **[`extended_compat/metta-examples/SICP_book/`](extended_compat/metta-examples/SICP_book/):** SICP Book Examples in Metta
  - [Chapter 1.1](extended_compat/metta-examples/SICP_book/chapter_1_1.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/SICP_book/chapter_1_1.metta.html)
  - [Chapter 1.2](extended_compat/metta-examples/SICP_book/chapter_1_2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/SICP_book/chapter_1_2.metta.html)
  - [Chapter 1.3](extended_compat/metta-examples/SICP_book/chapter_1_3.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/SICP_book/chapter_1_3.metta.html)

### Recursion Schemes
- **[`extended_compat/metta-examples/recursion-schemes/src/`](extended_compat/metta-examples/recursion-schemes/src/):** Recursion Schemes in Metta
   - [`schemes.metta`](extended_compat/metta-examples/recursion-schemes/src/schemes.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/recursion-schemes/src/schemes.metta.html): Various recursion schemes implemented in Metta.
   - [`base.metta`](extended_compat/metta-examples/recursion-schemes/src/base.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/recursion-schemes/src/base.metta.html): Base functions and utilities for recursion schemes.
   - [`expression.metta`](extended_compat/metta-examples/recursion-schemes/src/expression.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/recursion-schemes/src/expression.metta.html): Expression handling in recursion schemes.
   - [`benchmark.metta`](extended_compat/metta-examples/recursion-schemes/src/benchmark.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/recursion-schemes/src/benchmark.metta.html): Benchmark tests for recursion scheme implementations.

### Probabilistic Dependent Types
- **[`extended_compat/metta-examples/prob-dep-types/`](extended_compat/metta-examples/prob-dep-types/):** Probabilistic Dependent Types in Metta
   - [`prob_dep_types.metta`](extended_compat/metta-examples/prob-dep-types/prob_dep_types.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/prob-dep-types/prob_dep_types.metta.html): Definitions and examples of probabilistic dependent types.
   - [`inf_order_probs.metta`](extended_compat/metta-examples/prob-dep-types/inf_order_probs.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/metta-examples/prob-dep-types/inf_order_probs.metta.html): Infinite order probabilities and their applications.

## NARS (Non-Axiomatic Reasoning System)

#### **NARS - Current Version**
- **[`nars/current`](./extended_compat/nars/current)**: The current iteration of the Non-Axiomatic Reasoning System (NARS) showcasing the latest features and tests.
  - [`NARS.metta`](extended_compat/nars/current/NARS.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/current/NARS.metta.html): Main script for the current version of NARS.
  - [`tests0.metta`](extended_compat/nars/current/tests0.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/current/tests0.metta.html): Basic tests for the current NARS version.
  - [`tests1.metta`](extended_compat/nars/current/tests1.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/current/tests1.metta.html): Comprehensive level tests for NARS functionalities.
  - [`tests2.metta`](extended_compat/nars/current/tests2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/current/tests2.metta.html): Advanced testing scenarios for NARS.
  - [`tests3.metta`](extended_compat/nars/current/tests3.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/current/tests3.metta.html): Tests focusing on specific reasoning capabilities in NARS.
  - [`tests4.metta`](extended_compat/nars/current/tests4.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/current/tests4.metta.html): Specialized tests for complex reasoning in NARS.
  - [`tests5.metta`](extended_compat/nars/current/tests5.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/current/tests5.metta.html): Simple test for complex reasoning in NARS.

#### **NARS - New Developments**
- **[`nars/new`](./extended_compat/nars/new)**: Houses the latest developments and experimental features in NARS.
  - [`NARS.metta`](extended_compat/nars/new/NARS.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/new/NARS.metta.html)[`tests0.metta`](extended_compat/nars/new/tests0.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/new/tests0.metta.html)[`tests1.metta`](extended_compat/nars/new/tests1.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/new/tests1.metta.html)[`tests2.metta`](extended_compat/nars/new/tests2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/new/tests2.metta.html)[`tests3.metta`](extended_compat/nars/new/tests3.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/new/tests3.metta.html)[`tests4.metta`](extended_compat/nars/new/tests4.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/new/tests4.metta.html)[`tests5.metta`](extended_compat/nars/new/tests5.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/new/tests5.metta.html): Reflects ongoing experiments and cutting-edge features in NARS development.

#### **NARS Extras**
- **[`nars/nars_extras`](./extended_compat/nars/nars_extras)**: Additional scripts and utilities for NARS.
  - [`NARS_BuildTupleCounts.metta`](extended_compat/nars/nars_extras/NARS_BuildTupleCounts.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_extras/NARS_BuildTupleCounts.metta.html): Script for building tuple counts in NARS.
  - [`RUN_minnars.metta`](extended_compat/nars/nars_extras/RUN_minnars.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_extras/RUN_minnars.metta.html): Execution script for MinNARS, a minimalistic version of NARS.
  - [`RUN_minnars_trimmed.metta`](extended_compat/nars/nars_extras/RUN_minnars_trimmed.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_extras/RUN_minnars_trimmed.metta.html): Trimmed version of the MinNARS execution script.
  - [`TestNARS_listing.metta`](extended_compat/nars/nars_extras/TestNARS_listing.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_extras/TestNARS_listing.metta.html): Comprehensive test listings and scripts for NARS.

#### **NARS - Previous Versions**
- **[`nars/prev`](./extended_compat/nars/prev)**: Includes tests and scripts from previous versions of NARS, showcasing the evolution of the system.
  - [`NARS.metta`](extended_compat/nars/prev/NARS.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/prev/NARS.metta.html)[`tests0.metta`](extended_compat/nars/prev/tests0.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/prev/tests0.metta.html)[`tests1.metta`](extended_compat/nars/prev/tests1.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/prev/tests1.metta.html)[`tests2.metta`](extended_compat/nars/prev/tests2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/prev/tests2.metta.html)[`tests3.metta`](extended_compat/nars/prev/tests3.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/prev/tests3.metta.html)[`tests4.metta`](extended_compat/nars/prev/tests4.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/prev/tests4.metta.html)[`tests5.metta`](extended_compat/nars/prev/tests5.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/prev/tests5.metta.html): Provides a historical perspective on the progression and updates in NARS.

#### **NARS Version 0**
- **[`nars/nars_v0`](./extended_compat/nars/nars_v0)**: The original version of NARS, preserving the initial features and tests.
  - [`NARS.metta`](extended_compat/nars/nars_v0/NARS.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_v0/NARS.metta.html): Main script for the original NARS version.
  - [`NARS-old.metta`](extended_compat/nars/nars_v0/NARS-old.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_v0/NARS-old.metta.html): Older version of the NARS main script.
  - [`tests0.metta`](extended_compat/nars/nars_v0/tests0.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_v0/tests0.metta.html)[`tests1.metta`](extended_compat/nars/nars_v0/tests1.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_v0/tests1.metta.html)[`tests2.metta`](extended_compat/nars/nars_v0/tests2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_v0/tests2.metta.html)[`tests3.metta`](extended_compat/nars/nars_v0/tests3.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_v0/tests3.metta.html)[`tests4.metta`](extended_compat/nars/nars_v0/tests4.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_v0/tests4.metta.html)[`tests5.metta`](extended_compat/nars/nars_v0/tests5.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/nars/nars_v0/tests5.metta.html) A series of tests ranging from basic to comprehensive for the original NARS version.




## Python Compatibility - Hyperon Experimental Python

- **[`python_compat/hyperon-experimental_python/sandbox/`](python_compat/hyperon-experimental_python/sandbox/):** Hyperon Experimental Python Sandbox
   - [`resolve/r.metta`](python_compat/hyperon-experimental_python/sandbox/resolve/r.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/hyperon-experimental_python/sandbox/resolve/r.metta.html): Resolution algorithms in Hyperon Python sandbox.
   - [`sql_space/sql_space_test.metta`](python_compat/hyperon-experimental_python/sandbox/sql_space/sql_space_test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/hyperon-experimental_python/sandbox/sql_space/sql_space_test.metta.html): Test scripts for SQL space integration in Hyperon.
   - [`neurospace/test_assist.metta`](python_compat/hyperon-experimental_python/sandbox/neurospace/test_assist.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/hyperon-experimental_python/sandbox/neurospace/test_assist.metta.html): Assistant scripts for neurospace simulations.
   - [`neurospace/test_nspace.metta`](python_compat/hyperon-experimental_python/sandbox/neurospace/test_nspace.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/hyperon-experimental_python/sandbox/neurospace/test_nspace.metta.html): Neurospace testing and simulation scripts.
   - [`numpy/nm_test.metta`](python_compat/hyperon-experimental_python/sandbox/numpy/nm_test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/hyperon-experimental_python/sandbox/numpy/nm_test.metta.html): Numpy integration tests in Hyperon Python environment.
   - [`das_gate/test_das.metta`](python_compat/hyperon-experimental_python/sandbox/das_gate/test_das.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/hyperon-experimental_python/sandbox/das_gate/test_das.metta.html): Test scripts for DAS gate functionality in Hyperon.

- **[`python_compat/extend/`](python_compat/extend/):** Metta-Morph Python Compatibility Layer for NARS
	   - [`example6.metta`](python_compat/extend/example6.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/extend/example6.metta.html): Example script 6 for Python compatibility layer.
	   - [`compileme.metta`](python_compat/extend/compileme.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/extend/compileme.metta.html): Compilation scripts for Python compatibility extensions.
	   - [`example2.metta`](python_compat/extend/example2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/extend/example2.metta.html): Example script 2 for extended functionalities.
	   - [`example5.metta`](python_compat/extend/example5.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/extend/example5.metta.html): Example script 5 showcasing extended features.
	   - [`example4.metta`](python_compat/extend/example4.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/extend/example4.metta.html): Example script 4 demonstrating extended capabilities.
	   - [`example1.metta`](python_compat/extend/example1.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/extend/example1.metta.html): Example script 1 for Python compatibility tests.
	   - [`example3.metta`](python_compat/extend/example3.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/extend/example3.metta.html): Example script 3 in Python compatibility layer.
	   - [`timing.metta`](python_compat/timing/timing.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/timing/timing.metta.html): Timing and performance testing scripts.
	   - [`mettamorph.metta`](python_compat/mettamorph.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/python_compat/mettamorph.metta.html): Inital Script of MeTTa-Morph.


#### **Synthesis and Logic Group**

This group of directories explores various representational methods for porting PLN to MeTTa.
- **[`extended_compat/hyperon-pln/metta/`](extended_compat/hyperon-pln/metta/):** Hyperon PLN Metta Base Compatibility

- **[`entail`](./extended_compat/hyperon-pln/metta/entail)**: Here, rules are expressed with the symbol `?`.
   - [`DeductionEntailTest.metta`](extended_compat/hyperon-pln/metta/entail/DeductionEntailTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/entail/DeductionEntailTest.metta.html): Tests for deduction entailment in MeTTa.
   - [`ImplicationDirectIntroductionEntail.metta`](extended_compat/hyperon-pln/metta/entail/ImplicationDirectIntroductionEntail.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/entail/ImplicationDirectIntroductionEntail.metta.html): Direct implication introduction entailment logic.
   - [`ImplicationDirectIntroductionEntailTest.metta`](extended_compat/hyperon-pln/metta/entail/ImplicationDirectIntroductionEntailTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/entail/ImplicationDirectIntroductionEntailTest.metta.html): Tests for direct implication introduction entailment.
   - [`DeductionEntail.metta`](extended_compat/hyperon-pln/metta/entail/DeductionEntail.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/entail/DeductionEntail.metta.html): Logic for deduction entailment in MeTTa.

- **[`common`](./extended_compat/hyperon-pln/metta/common)**: Contains common definitions for PLN in MeTTa.
   - [`Num.metta`](extended_compat/hyperon-pln/metta/common/Num.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/Num.metta.html): Numerical utilities and definitions.
   - [`Record.metta`](extended_compat/hyperon-pln/metta/common/Record.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/Record.metta.html): Record structures and related logic.
   - [`DeductionFormula.metta`](extended_compat/hyperon-pln/metta/common/formula/DeductionFormula.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/formula/DeductionFormula.metta.html): Formulae for logical deduction.
   - [`ImplicationDirectIntroductionFormula.metta`](extended_compat/hyperon-pln/metta/common/formula/ImplicationDirectIntroductionFormula.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/formula/ImplicationDirectIntroductionFormula.metta.html): Formulae for direct implication introduction.
   - [`ModusPonensFormula.metta`](extended_compat/hyperon-pln/metta/common/formula/ModusPonensFormula.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/formula/ModusPonensFormula.metta.html): Formulae for modus ponens logic.
   - [`DeductionFormulaTest.metta`](extended_compat/hyperon-pln/metta/common/formula/DeductionFormulaTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/formula/DeductionFormulaTest.metta.html): Test cases for logical deduction formulae.
   - [`OrderedSet.metta`](extended_compat/hyperon-pln/metta/common/OrderedSet.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/OrderedSet.metta.html): Implementation of ordered sets.
   - [`EqualityType.metta`](extended_compat/hyperon-pln/metta/common/EqualityType.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/EqualityType.metta.html): Equality types and related logic.
   - [`ListTest.metta`](extended_compat/hyperon-pln/metta/common/ListTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/ListTest.metta.html): Tests for list operations.
   - [`NumTest.metta`](extended_compat/hyperon-pln/metta/common/NumTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/NumTest.metta.html): Tests for numerical utilities.
   - [`OrderedSetTest.metta`](extended_compat/hyperon-pln/metta/common/OrderedSetTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/OrderedSetTest.metta.html): Tests for ordered set implementation.
   - [`Num8.metta`](extended_compat/hyperon-pln/metta/common/Num8.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/Num8.metta.html): Extended numerical operations.
   - [`Maybe.metta`](extended_compat/hyperon-pln/metta/common/Maybe.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/Maybe.metta.html): Implementation of 'Maybe' monad.
   - [`MaybeTest.metta`](extended_compat/hyperon-pln/metta/common/MaybeTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/MaybeTest.metta.html): Tests for 'Maybe' monad.
   - [`EqualityTypeTest.metta`](extended_compat/hyperon-pln/metta/common/EqualityTypeTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/EqualityTypeTest.metta.html): Tests for equality type logic.
   - [`In.metta`](extended_compat/hyperon-pln/metta/common/In.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/In.metta.html): Logic for element inclusion.
   - [`List.metta`](extended_compat/hyperon-pln/metta/common/List.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/List.metta.html): List operations and utilities.
   - [`TruthValue.metta`](extended_compat/hyperon-pln/metta/common/truthvalue/TruthValue.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/truthvalue/TruthValue.metta.html): Base structure for truth values.
   - [`EvidentialTruthValue.metta`](extended_compat/hyperon-pln/metta/common/truthvalue/EvidentialTruthValue.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/truthvalue/EvidentialTruthValue.metta.html): Evidential truth value implementation.
   - [`EvidentialTruthValueTest.metta`](extended_compat/hyperon-pln/metta/common/truthvalue/EvidentialTruthValueTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/truthvalue/EvidentialTruthValueTest.metta.html): Evidential truth value Tests.
   - [`TruthValueTest.metta`](extended_compat/hyperon-pln/metta/common/truthvalue/TruthValueTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/truthvalue/TruthValueTest.metta.html): General tests for truth values.
   - [`TemporalTruthValue.metta`](extended_compat/hyperon-pln/metta/common/truthvalue/TemporalTruthValue.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/truthvalue/TemporalTruthValue.metta.html): Temporal aspect of truth values.
   - [`MeasEq.metta`](extended_compat/hyperon-pln/metta/common/truthvalue/MeasEq.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/truthvalue/MeasEq.metta.html): Measurement equality logic.
   - [`InTest.metta`](extended_compat/hyperon-pln/metta/common/InTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/InTest.metta.html): Tests for element inclusion logic.
   - [`BelieveMe.metta`](extended_compat/hyperon-pln/metta/common/BelieveMe.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/common/BelieveMe.metta.html): Logic for belief representation.

- **[`HOL`](./extended_compat/hyperon-pln/metta/hol)**: Showcases HOL (Higher-Order Logic) operations.
   - [`ListTest.metta`](extended_compat/hyperon-pln/metta/hol/ListTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/hol/ListTest.metta.html): Test cases for list operations in HOL.
   - [`NatTest.metta`](extended_compat/hyperon-pln/metta/hol/NatTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/hol/NatTest.metta.html): Test cases for natural number operations in HOL.
   - [`NatSimpleTest.metta`](extended_compat/hyperon-pln/metta/hol/NatSimpleTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/hol/NatSimpleTest.metta.html): Simplified tests for natural numbers in HOL.

- **[`dependent-types`](./extended_compat/hyperon-pln/metta/dependent-types)**: Concentrates on representing rules as type constructors.
   - [`ModusPonensDTLTest.metta`](extended_compat/hyperon-pln/metta/dependent-types/ModusPonensDTLTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/dependent-types/ModusPonensDTLTest.metta.html): Test cases for modus ponens in dependent type logic.
   - [`ImplicationDirectIntroductionDTL.metta`](extended_compat/hyperon-pln/metta/dependent-types/ImplicationDirectIntroductionDTL.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/dependent-types/ImplicationDirectIntroductionDTL.metta.html): Direct implication introduction in dependent type logic.
   - [`DeductionImplicationDirectIntroductionDTLTest.metta`](extended_compat/hyperon-pln/metta/dependent-types/DeductionImplicationDirectIntroductionDTLTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/dependent-types/DeductionImplicationDirectIntroductionDTLTest.metta.html): Tests for deduction and direct implication introduction.
   - [`ImplicationDirectIntroductionDTLTest.metta`](extended_compat/hyperon-pln/metta/dependent-types/ImplicationDirectIntroductionDTLTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/dependent-types/ImplicationDirectIntroductionDTLTest.metta.html): More tests for direct implication introduction.
   - [`DeductionDTL.metta`](extended_compat/hyperon-pln/metta/dependent-types/DeductionDTL.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/dependent-types/DeductionDTL.metta.html): Deduction logic in dependent type language.
   - [`DeductionDTLTest.metta`](extended_compat/hyperon-pln/metta/dependent-types/DeductionDTLTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/dependent-types/DeductionDTLTest.metta.html): Tests for deduction in dependent type language.
   - [`ModusPonensDTL.metta`](extended_compat/hyperon-pln/metta/dependent-types/ModusPonensDTL.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/dependent-types/ModusPonensDTL.metta.html): Modus ponens implementation in dependent type language.

- **[`forward-chainer`](./extended_compat/hyperon-pln/metta/forward-chainer)**: Focuses on forward-chaining logic.
   - [`forward-chainer-test.metta`](extended_compat/hyperon-pln/metta/forward-chainer/forward-chainer-test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/forward-chainer/forward-chainer-test.metta.html): Test cases for forward-chaining logic.
   - [`forward-chainer-xp.metta`](extended_compat/hyperon-pln/metta/forward-chainer/forward-chainer-xp.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/forward-chainer/forward-chainer-xp.metta.html): Experimental forward-chaining implementations.

- **[`subtyping`](./extended_compat/hyperon-pln/metta/subtyping)**: Showcases subtyping operations.
   - [`rule-base.metta`](extended_compat/hyperon-pln/metta/subtyping/rule-base.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/subtyping/rule-base.metta.html): Base rules for subtyping operations.
   - [`subtyping-test.metta`](extended_compat/hyperon-pln/metta/subtyping/subtyping-test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/subtyping/subtyping-test.metta.html): Test cases for subtyping.

- **[`sumo`](./extended_compat/hyperon-pln/metta/sumo)**: Houses SUMO (Suggested Upper Merged Ontology) examples.
    - [`load-suo-kif.metta`](extended_compat/hyperon-pln/metta/sumo/load-suo-kif.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/sumo/load-suo-kif.metta.html): Logic for loading SUMO KIF files.
    - [`rule-base.metta`](extended_compat/hyperon-pln/metta/sumo/rule-base.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/sumo/rule-base.metta.html): Base rules for SUMO logic.
   - **[`sumo/john-carry-flower`](./extended_compat/hyperon-pln/metta/sumo/john-carry-flower)**: Narrative logic examples.
      - [`john-carry-flower-test.metta`](extended_compat/hyperon-pln/metta/sumo/john-carry-flower/john-carry-flower-test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/sumo/john-carry-flower/john-carry-flower-test.metta.html): Test cases for the John carrying a flower narrative.
      - [`john-carry-flower.kif.metta`](extended_compat/hyperon-pln/metta/sumo/john-carry-flower/john-carry-flower.kif.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/sumo/john-carry-flower/john-carry-flower.kif.metta.html): KIF narrative for John carrying a flower.
    - **[`sumo/orientation`](./extended_compat/hyperon-pln/metta/sumo/orientation)**: Related to spatial orientation.
      - [`orientation-test.metta`](extended_compat/hyperon-pln/metta/sumo/orientation/orientation-test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/sumo/orientation/orientation-test.metta.html): Tests for orientation logic in SUMO.
      - [`orientation.kif.metta`](extended_compat/hyperon-pln/metta/sumo/orientation/orientation.kif.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/sumo/orientation/orientation.kif.metta.html): Knowledge Interchange Format files for orientation.
    - **[`sumo/located`](./extended_compat/hyperon-pln/metta/sumo/located)**: Pertains to location-based logic.
      - [`located-test.metta`](extended_compat/hyperon-pln/metta/sumo/located/located-test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/sumo/located/located-test.metta.html): Tests for location-based logic in SUMO.
      - [`located.kif.metta`](extended_compat/hyperon-pln/metta/sumo/located/located.kif.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/sumo/located/located.kif.metta.html): KIF files for location-based logic.
    - **[`sumo/route-between`](./extended_compat/hyperon-pln/metta/sumo/route-between)**: Deals with routing logic.

#### **Synthesis Experiments**

- **[`synthesis/experiments`](./extended_compat/hyperon-pln/metta/synthesis/experiments)**: Experiments in program synthesis.
   - [`synthesize-via-unify-test.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-unify-test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-unify-test.metta.html): Tests for synthesis through unification.
   - [`unify-via-case.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/unify-via-case.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/unify-via-case.metta.html): Unification via `case` operator construct.
   - [`synthesize-via-case.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-case.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-case.metta.html): Synthesis through `case` operator construct.
   - [`synthesize-via-let.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-let.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-let.metta.html): Synthesis using the 'let' construct.
   - [`synthesize-via-unify.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-unify.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-unify.metta.html): Synthesis through unification techniques.
   - [`synthesize-via-let-test.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-let-test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-let-test.metta.html): Tests for synthesis using the 'let' construct.
   - [`synthesize-via-case-test.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-case-test.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-case-test.metta.html): Tests for synthesis through `case` operator construct.
   - [`unify-via-let.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/unify-via-let.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/unify-via-let.metta.html): Unification using the 'let' construct.
   - [`non-determinism.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/non-determinism.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/non-determinism.metta.html): Explorations of non-determinism in synthesis.
   - [`synthesize-via-superpose.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-superpose.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-superpose.metta.html): Synthesis through superposition.
   - [`synthesize-via-type-checking.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-type-checking.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-type-checking.metta.html): Synthesis with type checking.
   - [`self-contained-synthesize.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/self-contained-synthesize.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/self-contained-synthesize.metta.html): Self-contained examples of synthesis.
   - [`synthesize-via-unify-test-longer.metta`](extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-unify-test-longer.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/synthesis/experiments/synthesize-via-unify-test-longer.metta.html): Extended tests for synthesis through unification.

#### **Match and Unify Operations**

- **[`match`](./extended_compat/hyperon-pln/metta/match)**: Logic for matching and unification.
   - [`DeductionImplicationDirectIntroductionMatchTest.metta`](extended_compat/hyperon-pln/metta/match/DeductionImplicationDirectIntroductionMatchTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/match/DeductionImplicationDirectIntroductionMatchTest.metta.html): Tests for matching in deduction and direct implication introduction.
   - [`DeductionMatch.metta`](extended_compat/hyperon-pln/metta/match/DeductionMatch.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/match/DeductionMatch.metta.html): Logic for deduction matching.
   - [`ImplicationDirectIntroductionMatchTest.metta`](extended_compat/hyperon-pln/metta/match/ImplicationDirectIntroductionMatchTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/match/ImplicationDirectIntroductionMatchTest.metta.html): Tests for direct implication introduction matching.
   - [`DeductionMatchTest.metta`](extended_compat/hyperon-pln/metta/match/DeductionMatchTest.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/match/DeductionMatchTest.metta.html): Test cases for deduction matching.
   - [`ImplicationDirectIntroductionMatch.metta`](extended_compat/hyperon-pln/metta/match/ImplicationDirectIntroductionMatch.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/extended_compat/hyperon-pln/metta/match/ImplicationDirectIntroductionMatch.metta.html): Logic for direct implication introduction matching.

#### **Metta-Morph Tests**

- **[`metta-morph_tests`](./baseline_compat/metta-morph_tests)**: Test cases exploring various features and functionalities in MeTTa.
   - [`minnars.metta`](baseline_compat/metta-morph_tests/minnars.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/minnars.metta.html): Tests and examples for MinNARS implementation.
   - [`sequential_nested.metta`](baseline_compat/metta-morph_tests/sequential_nested.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/sequential_nested.metta.html): Experiments with sequential and nested structures.
   - [`peano.metta`](baseline_compat/metta-morph_tests/peano.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/peano.metta.html): Implementations and tests for Peano arithmetic.
   - [`if.metta`](baseline_compat/metta-morph_tests/if.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/if.metta.html): Tests for 'if' conditional structures.
   - [`types.metta`](baseline_compat/metta-morph_tests/types.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/types.metta.html): Exploration of type systems and their behaviors.
   - [`states_spaces.metta`](baseline_compat/metta-morph_tests/states_spaces.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/states_spaces.metta.html): Experiments with state spaces.
   - [`supercollapse.metta`](baseline_compat/metta-morph_tests/supercollapse.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/supercollapse.metta.html): Tests for collapse operations.
   - [`zeroargs.metta`](baseline_compat/metta-morph_tests/zeroargs.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/zeroargs.metta.html): Investigating functions with zero arguments.
   - [`match_feval.metta`](baseline_compat/metta-morph_tests/match_feval.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/match_feval.metta.html): Function evaluation within match structures.
   - [`nalifier.metta`](baseline_compat/metta-morph_tests/nalifier.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/nalifier.metta.html): NAL (Non-Axiomatic Logic) implementation tests.
   - [`factorial.metta`](baseline_compat/metta-morph_tests/factorial.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/factorial.metta.html): Factorial function implementations and tests.
   - [`types2.metta`](baseline_compat/metta-morph_tests/types2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/types2.metta.html): Further exploration into types and their applications.
   - [`and_or.metta`](baseline_compat/metta-morph_tests/and_or.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/and_or.metta.html): Logical operations and their behavior in different contexts.
   - [`let_superpose_list.metta`](baseline_compat/metta-morph_tests/let_superpose_list.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/let_superpose_list.metta.html): Experiments with 'let' in list `superpose`.
   - [`multifunction.metta`](baseline_compat/metta-morph_tests/multifunction.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/multifunction.metta.html): Tests for multifunctional behaviors.
   - [`match_void.metta`](baseline_compat/metta-morph_tests/match_void.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/match_void.metta.html): Exploring match operations with void returns.
   - [`let_superpose_if_case.metta`](baseline_compat/metta-morph_tests/let_superpose_if_case.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/let_superpose_if_case.metta.html): Superposing 'let' with 'if' and 'case' structures.
   - [`types3.metta`](baseline_compat/metta-morph_tests/types3.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/types3.metta.html): Advanced type system explorations.
   - [`add_atom_match.metta`](baseline_compat/metta-morph_tests/add_atom_match.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/add_atom_match.metta.html): Atom addition within match structures.
   - [`let_superpose_list2.metta`](baseline_compat/metta-morph_tests/let_superpose_list2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/let_superpose_list2.metta.html): Advanced list superposition with 'let'.
   - [`superpose_nested.metta`](baseline_compat/metta-morph_tests/superpose_nested.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/superpose_nested.metta.html): Nested structure `superpose`.
   - [`identity.metta`](baseline_compat/metta-morph_tests/identity.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/identity.metta.html): Tests for identity functions and operations.
   - [`nested_parameters.metta`](baseline_compat/metta-morph_tests/nested_parameters.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/nested_parameters.metta.html): Experiments with nested parameter structures.
   - [`match_superposed_spaces.metta`](baseline_compat/metta-morph_tests/match_superposed_spaces.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/match_superposed_spaces.metta.html): Matching within superposed spaces.
   - [`collapse.metta`](baseline_compat/metta-morph_tests/collapse.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/collapse.metta.html): Tests for collapse operations in various contexts.
   - [`letlet.metta`](baseline_compat/metta-morph_tests/letlet.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/metta-morph_tests/letlet.metta.html): Experiments with nested 'let' structures.

#### **MeTTaLog Sanity Tests**

- **[`hyperon-mettalog_sanity`](./baseline_compat/hyperon-mettalog_sanity)**: Sanity checks and basic tests for Hyperon Mettalog.
   - [`02-curried-plus.metta`](baseline_compat/hyperon-mettalog_sanity/02-curried-plus.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/02-curried-plus.metta.html): Implementations and tests for curried addition functions.
   - [`00_lang_case.metta`](baseline_compat/hyperon-mettalog_sanity/00_lang_case.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/00_lang_case.metta.html): Case studies in language design and implementation.
   - [`01_lang_inc.metta`](baseline_compat/hyperon-mettalog_sanity/01_lang_inc.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/01_lang_inc.metta.html): Increment functions and their usage in language testing.
   - [`04_match_list_like_space.metta`](baseline_compat/hyperon-mettalog_sanity/04_match_list_like_space.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/04_match_list_like_space.metta.html): Matching lists in space-like structures.
   - [`structure-tests.metta`](baseline_compat/hyperon-mettalog_sanity/structure-tests.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/structure-tests.metta.html): Structural tests for sanity checking.
   - [`05_match_superpose_element_like_space.metta`](baseline_compat/hyperon-mettalog_sanity/05_match_superpose_element_like_space.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/05_match_superpose_element_like_space.metta.html): Matching tests with superposition in element-like spaces.
   - [`00_lang_ok_to_redefine.metta`](baseline_compat/hyperon-mettalog_sanity/00_lang_ok_to_redefine.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/00_lang_ok_to_redefine.metta.html): Tests for language redefinition capabilities.

#### **Hyperon Mettalog Sanity Checks**

- **[`hyperon-mettalog_sanity`](./baseline_compat/hyperon-mettalog_sanity)**: Sanity checks and basic tests for Hyperon Mettalog.
   - [`02-curried-plus.metta`](baseline_compat/hyperon-mettalog_sanity/02-curried-plus.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/02-curried-plus.metta.html): Implementations and tests for curried addition functions.
   - [`00_lang_case.metta`](baseline_compat/hyperon-mettalog_sanity/00_lang_case.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/00_lang_case.metta.html): Case studies in language design and implementation.
   - [`01_lang_inc.metta`](baseline_compat/hyperon-mettalog_sanity/01_lang_inc.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/01_lang_inc.metta.html): Increment functions and their usage in language testing.
   - [`04_match_list_like_space.metta`](baseline_compat/hyperon-mettalog_sanity/04_match_list_like_space.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-mettalog_sanity/04_match_list_like_space.metta.html): Matching lists in space-like structures.

#### **Hyperon/MeTTa base Unit Tests**

- **[`hyperon-experimental_scripts`](./baseline_compat/hyperon-experimental_scripts)**: Scripts for experimenting with advanced concepts in Hyperon.
   - [`_e2_states_dia.metta`](baseline_compat/hyperon-experimental_scripts/_e2_states_dia.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/_e2_states_dia.metta.html): State diagrams and their representation.
   - [`a1_symbols.metta`](baseline_compat/hyperon-experimental_scripts/a1_symbols.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/a1_symbols.metta.html): Exploration of symbol usage and manipulation.
   - [`d4_type_prop.metta`](baseline_compat/hyperon-experimental_scripts/d4_type_prop.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/d4_type_prop.metta.html): Type properties and their applications in logic.
   - [`c2_spaces_kb.metta`](baseline_compat/hyperon-experimental_scripts/c2_spaces_kb.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/c2_spaces_kb.metta.html): Knowledge base management for spaces.
   - [`b1_equal_chain.metta`](baseline_compat/hyperon-experimental_scripts/b1_equal_chain.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/b1_equal_chain.metta.html): Chain of equalities and logical implications.
   - [`e1_kb_write.metta`](baseline_compat/hyperon-experimental_scripts/e1_kb_write.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/e1_kb_write.metta.html): Writing and managing knowledge bases.
   - [`d3_deptypes.metta`](baseline_compat/hyperon-experimental_scripts/d3_deptypes.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/d3_deptypes.metta.html): Explorations of dependent types in logic.
   - [`c3_pln_stv.metta`](baseline_compat/hyperon-experimental_scripts/c3_pln_stv.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/c3_pln_stv.metta.html): PLN short-term visit logic and reasoning.
   - [`d5_auto_types.metta`](baseline_compat/hyperon-experimental_scripts/d5_auto_types.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/d5_auto_types.metta.html): Automatic type inference and checking.
   - [`b5_types_prelim.metta`](baseline_compat/hyperon-experimental_scripts/b5_types_prelim.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/b5_types_prelim.metta.html): Preliminary studies on types in logic.
   - [`e3_match_states.metta`](baseline_compat/hyperon-experimental_scripts/e3_match_states.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/e3_match_states.metta.html): State matching and logic testing.
   - [`d2_higherfunc.metta`](baseline_compat/hyperon-experimental_scripts/d2_higherfunc.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/d2_higherfunc.metta.html): Higher-order functions and their applications.
   - [`b3_direct.metta`](baseline_compat/hyperon-experimental_scripts/b3_direct.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/b3_direct.metta.html): Direct methods in logical reasoning and computation.
   - [`e2_states.metta`](baseline_compat/hyperon-experimental_scripts/e2_states.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/e2_states.metta.html): State management and logic in complex systems.
   - [`d1_gadt.metta`](baseline_compat/hyperon-experimental_scripts/d1_gadt.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/d1_gadt.metta.html): Generalized Algebraic Data Types (GADT) exploration.
   - [`c1_grounded_basic.metta`](baseline_compat/hyperon-experimental_scripts/c1_grounded_basic.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/c1_grounded_basic.metta.html): Grounded basics in logical computation.
   - [`f1_imports.metta`](baseline_compat/hyperon-experimental_scripts/f1_imports.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/f1_imports.metta.html): Importing external logic and data structures.
	   - [`f1_moduleA.metta`](baseline_compat/hyperon-experimental_scripts/f1_moduleA.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/f1_moduleA.metta.html): Module A
	   - [`f1_moduleB.metta`](baseline_compat/hyperon-experimental_scripts/f1_moduleB.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/f1_moduleB.metta.html): Module B
	   - [`f1_moduleC.metta`](baseline_compat/hyperon-experimental_scripts/f1_moduleC.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/f1_moduleC.metta.html): Module C
   - [`a3_twoside.metta`](baseline_compat/hyperon-experimental_scripts/a3_twoside.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/a3_twoside.metta.html): Two-sided logic and reasoning experiments.
   - [`b2_backchain.metta`](baseline_compat/hyperon-experimental_scripts/b2_backchain.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/b2_backchain.metta.html): Backchaining techniques in logical reasoning.
   - [`a2_opencoggy.metta`](baseline_compat/hyperon-experimental_scripts/a2_opencoggy.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/a2_opencoggy.metta.html): Experiments with OpenCog-like structures.
   - [`b4_nondeterm.metta`](baseline_compat/hyperon-experimental_scripts/b4_nondeterm.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/b4_nondeterm.metta.html): Non-deterministic approaches in logic.
   - [`c2_spaces.metta`](baseline_compat/hyperon-experimental_scripts/c2_spaces.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/c2_spaces.metta.html): Space(s) handling and reasoning in logic.
   - [`b0_chaining_prelim.metta`](baseline_compat/hyperon-experimental_scripts/b0_chaining_prelim.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/baseline_compat/hyperon-experimental_scripts/b0_chaining_prelim.metta.html): Preliminary chaining methods in logic.


### **Feature Demonstrations**

#### **Bidirectional Computation**
- **[`features/bidirectional_computation`](./features/bidirectional_computation)**: Demonstrates bidirectional computation, showcasing how operations can be reversed.
  - [`reverse-arithmetic.metta`](features/bidirectional_computation/reverse-arithmetic.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/bidirectional_computation/reverse-arithmetic.metta.html): Implements reverse arithmetic operations.
  - [`reverse-functions.metta`](features/bidirectional_computation/reverse-functions.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/bidirectional_computation/reverse-functions.metta.html): Demonstrates functions operating in reverse.
  - [`send-more.metta`](features/bidirectional_computation/send-more.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/bidirectional_computation/send-more.metta.html): Solves the SEND+MORE cryptarithmetic puzzle.
  - [`send-more-money.metta`](features/bidirectional_computation/send-more-money.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/bidirectional_computation/send-more-money.metta.html): Tackles the SEND+MORE=MONEY problem with bidirectional computation.

#### **Containers as Spaces**
- **[`features/containers_are_spaces`](./features/containers_are_spaces)**: Illustrates how containers can act as spatial structures in computation.
  - [`04_match_list_like_space.metta`](features/containers_are_spaces/04_match_list_like_space.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/containers_are_spaces/04_match_list_like_space.metta.html): Demonstrates list-like space matching.
  - [`05_match_superpose_element_like_space.metta`](features/containers_are_spaces/05_match_superpose_element_like_space.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/containers_are_spaces/05_match_superpose_element_like_space.metta.html): Shows superposition in element-like spaces.

#### **Host Language Features**
- **[`features/host_language`](./features/host_language)**: Features leveraging the host programming language(s) capabilities.
  - **[`compiler`](./features/host_language/compiler)**: Compiler-specific features and demonstrations.
    - [`00a_lang_compiled_case.metta`](features/host_language/compiler/00a_lang_compiled_case.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/host_language/compiler/00a_lang_compiled_case.metta.html): Explores compiled language case studies.
    - [`define_if_like.metta`](features/host_language/compiler/define_if_like.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/host_language/compiler/define_if_like.metta.html): Introduces compiler features for defining 'if'-like structures.
  - [`httpclient.metta`](features/host_language/httpclient.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/host_language/httpclient.metta.html): Implements a basic HTTP client.

#### **Loop Checks**
- **[`features/loop-checks`](./features/loop-checks)**: Experiments and tests to check for loops in computations.
  - [`06_loop_0.metta`](features/loop-checks/06_loop_0.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/loop-checks/06_loop_0.metta.html): Basic loop checking.
  - [`06_loop_1.metta`](features/loop-checks/06_loop_1.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/loop-checks/06_loop_1.metta.html): Intermediate loop checking.
  - [`06_loop_2.metta`](features/loop-checks/06_loop_2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/loop-checks/06_loop_2.metta.html): Advanced loop checking.

#### **Parallelism**
- **[`features/parallelism`](./features/parallelism)**: Showcases parallel computing with various algorithms and examples.
  - [`builtins.metta`](features/parallelism/builtins.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/parallelism/builtins.metta.html): Built-in parallel computing functions.


#### **Performance Testing and Benchmarking**

- **[`performance`](./performance)**: Performance tests and benchmarks showcasing optimization and efficiency.
  - [`factorial.metta`](performance/basic/factorial.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/factorial.metta.html): Factorial function implementation and performance testing.
  - [`factorial.pl`](./performance/basic/factorial.pl)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/factorial.pl.html): Hand-coded optimized version of the factorial function for speed.
  - [`fibo-as-pred.metta`](performance/basic/fibo-as-pred.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/fibo-as-pred.metta.html): Fibonacci sequence implementation as predicates.
  - [`fibo.metta`](performance/basic/fibo.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/fibo.metta.html): Basic Fibonacci sequence implementation.
  - [`fibonacci.pl`](./performance/basic/fibonacci.pl)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/fibonacci.pl.html): Hand-coded Fibonacci sequence for optimized performance.
  - [`fwgc1.metta`](performance/basic/fwgc1.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/fwgc1.metta.html): First version of the Farmer-Wolf-Goat-Cabbage problem.
  - [`fwgc2.metta`](performance/basic/fwgc2.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/fwgc2.metta.html): Second version of the problem with enhancements.
  - [`fwgc3.metta`](performance/basic/fwgc3.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/fwgc3.metta.html): Third version, further optimized for performance.
  - [`fwgc.metta`](performance/basic/fwgc.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/fwgc.metta.html): General implementation of the Farmer-Wolf-Goat-Cabbage problem.
  - [`hanoi-one-space.metta`](performance/basic/hanoi-one-space.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/hanoi-one-space.metta.html): Tower of Hanoi problem in a single space context.
  - [`hanoi-peg-space.metta`](performance/basic/hanoi-peg-space.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/hanoi-peg-space.metta.html): Tower of Hanoi with multiple pegs and spaces.
  - [`key-lookups-many.metta`](performance/basic/key-lookups-many.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/key-lookups-many.metta.html): Performance test for key lookups in large datasets.
  - [`pathfinding-easy-f.metta`](performance/basic/pathfinding-easy-f.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/pathfinding-easy-f.metta.html): Function-based solutions for easy-level pathfinding problems.
  - [`pathfinding-easy.metta`](performance/basic/pathfinding-easy.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/pathfinding-easy.metta.html): Easy-level pathfinding problems and solutions.
  - [`pathfinding-edge.metta`](performance/basic/pathfinding-edge.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/pathfinding-edge.metta.html): Edge-based pathfinding algorithms and tests.
  - [`pathfinding-hard-f.metta`](performance/basic/pathfinding-hard-f.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/pathfinding-hard-f.metta.html): Function-based solutions for hard-level pathfinding problems.
  - [`pathfinding-hard.metta`](performance/basic/pathfinding-hard.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/pathfinding-hard.metta.html): Hard-level pathfinding problems with complex algorithms.
  - [`pathfinding-med-f.metta`](performance/basic/pathfinding-med-f.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/pathfinding-med-f.metta.html): Medium difficulty pathfinding problems and function-based solutions.
  - [`state_types.metta`](performance/basic/state_types.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/state_types.metta.html): Demonstrations of various state types in logical problems.
  - [`talk80.metta`](performance/basic/talk80.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/talk80.metta.html): Implementation of the classic Talk-80 algorithm for NL parsing and querying.
  - [`test_infer_function_application_type.metta`](performance/basic/test_infer_function_application_type.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/test_infer_function_application_type.metta.html): Tests for inferring function application types.
  - [`test_list_concatenation.metta`](performance/basic/test_list_concatenation.metta)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/performance/basic/test_list_concatenation.metta.html): Tests for list concatenation performance.


#### ** MeTTaLog Higher Order Virtual Machine (HVM)**

      known for its pure functional runtime, lazy evaluation, non-garbage collection, and massive parallelism. HVM's beta-optimality allows it, in certain higher-order computations, to be exponentially faster than alternatives, including Haskell's GHC.

- **[`features/hvm`](./features/hvm)**: Demonstrates the capabilities of the Higher-order Virtual Machine (HVM),

  - **[`bugs`](./features/hvm/bugs)**: Bug demonstrations in HVM computations.
    - [`fib_dups.hvm`](features/hvm/bugs/fib_dups.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/bugs/fib_dups.hvm.html): Illustrates duplication issues in Fibonacci sequence calculation.
    - [`fib_loop.hvm`](features/hvm/bugs/fib_loop.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/bugs/fib_loop.hvm.html): Demonstrates a looping problem in Fibonacci computation.
    - [`fib_tups.hvm`](features/hvm/bugs/fib_tups.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/bugs/fib_tups.hvm.html): Showcases tuple-related problems in Fibonacci sequence.
    - [`lotto.hvm`](features/hvm/bugs/lotto.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/bugs/lotto.hvm.html): Presents a bug example in lottery number generation.

  - **[`callcc`](./features/hvm/callcc)**: Continuation-passing style (CPS) examples in HVM.
    - [`main.hvm`](features/hvm/callcc/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/callcc/main.hvm.html): Main script demonstrating CPS in HVM.

  - **[`hello`](./features/hvm/hello)**: Basic 'Hello World' example in HVM.
    - [`main.hvm`](features/hvm/hello/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/hello/main.hvm.html): Simple script to print 'Hello World' in HVM.

  - **[`IO`](./features/hvm/IO)**: Input/Output operations in HVM.
    - [`log.hvm`](features/hvm/IO/log.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/IO/log.hvm.html): Logging script in HVM.
    - [`query_and_print.hvm`](features/hvm/IO/query_and_print.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/IO/query_and_print.hvm.html): Script to query and print in HVM.
    - [`store_and_load.hvm`](features/hvm/IO/store_and_load.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/IO/store_and_load.hvm.html): Demonstrates storing and loading data.

  - **[`lambda`](./features/hvm/lambda)**: Lambda calculus examples in HVM.
    - **[`multiplication`](./features/hvm/lambda/multiplication)**: Multiplication using lambda calculus in HVM.
      - [`better.hvm`](features/hvm/lambda/multiplication/better.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/lambda/multiplication/better.hvm.html): Improved multiplication implementation.
      - [`main.hvm`](features/hvm/lambda/multiplication/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/lambda/multiplication/main.hvm.html): Basic multiplication script in lambda calculus.
      - [`main.hs`](features/hvm/lambda/multiplication/main.hs)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/lambda/multiplication/main.hs.html): Haskell version of the multiplication example.
    - **[`padic_clifford`](./features/hvm/lambda/padic_clifford)**: p-adic numbers and Clifford algebras in HVM.
      - [`main.hvm`](features/hvm/lambda/padic_clifford/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/lambda/padic_clifford/main.hvm.html): Demonstrates p-adic Clifford algebras.
    - **[`varbase`](./features/hvm/lambda/varbase)**: Variable-based calculations in HVM.
      - [`main.hvm`](features/hvm/lambda/varbase/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/lambda/varbase/main.hvm.html): Script for variable-based computation in lambda calculus.

  - **[`queue`](./features/hvm/queue)**: Queue implementation in HVM.
    - [`main.hvm`](features/hvm/queue/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/queue/main.hvm.html): Demonstrates a queue data structure in HVM.

  - **[`sort`](./features/hvm/sort)**: Sorting algorithms implemented in HVM.
    - **[`bitonic`](./features/hvm/sort/bitonic)**: Bitonic sort algorithm in HVM.
      - [`main.hvm`](features/hvm/sort/bitonic/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/sort/bitonic/main.hvm.html): Main script for bitonic sort.
      - [`main.hs`](features/hvm/sort/bitonic/main.hs)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/sort/bitonic/main.hs.html): Haskell version of bitonic sort.
    - **[`bubble`](./features/hvm/sort/bubble)**: Bubble sort algorithm in HVM.
      - [`main.hvm`](features/hvm/sort/bubble/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/sort/bubble/main.hvm.html): Main script for bubble sort.
      - [`main.hs`](features/hvm/sort/bubble/main.hs)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/sort/bubble/main.hs.html): Haskell version of bubble sort.
    - **[`quick`](./features/hvm/sort/quick)**: Quick sort algorithm in HVM.
      - [`main.hvm`](features/hvm/sort/quick/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/sort/quick/main.hvm.html): Main script for quick sort.
      - [`main.hs`](features/hvm/sort/quick/main.hs)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/sort/quick/main.hs.html): Haskell version of quick sort.
    - **[`radix`](./features/hvm/sort/radix)**: Radix sort algorithm in HVM.
      - [`main.hvm`](features/hvm/sort/radix/main.hvm)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/sort/radix/main.hvm.html): Main script for radix sort.
      - [`main.hs`](features/hvm/sort/radix/main.hs)[[output]](https://htmlpreview.github.io/?https://raw.githubusercontent.com/logicmoo/hyperon-wam/main/reports/features/hvm/sort/radix/main.hs.html): Haskell version of radix sort.


